@@ -133,7 +133,6 @@ class objearth():
             plt.show()
 
         elif type(DataArray) == numpy.ndarray:
-        #Area
             if area==True:
                 ymax = 0 ; ymin = DataArray.shape[0]
                 xmin = 0 ; xmax = DataArray.shape[1]
@@ -141,6 +140,7 @@ class objearth():
                 ymax = area[0] ; ymin = area[1]
                 xmin = area[2] ; xmax = area[3]
             real_margin_img = DataArray[ymax:ymin,xmin:xmax]
+            
             #plotshow
             plt.figure(figsize=(figsize))
             color_map = plt.imshow(real_margin_img,extent=[xmin,xmax,ymin,ymax])
@@ -155,9 +155,14 @@ class objearth():
 
             # faction
             im_ratio = real_margin_img.shape[1]/real_margin_img.shape[0]
-            fac = ratio(im_ratio)
+            if im_ratio<1:
+                fac = 0.0485
+            elif im_ratio==1:
+                fac = 0.045
+            else:
+                fac = 0.0456*(im_ratio**(-1.0113))
             #print(real_margin_img.shape[1],real_margin_img.shape[0],im_ratio,fac)
-            
+
             #colorbar
             min = real_margin_img.min()
             max = real_margin_img.max()
